@@ -6,7 +6,6 @@ from .cache import cacheit
 from .sympify import _sympify, sympify, SympifyError
 from .compatibility import (iterable, Iterator, ordered,
     string_types, with_metaclass, zip_longest, range)
-from .decorators import deprecated
 from .singleton import S
 
 from inspect import getmro
@@ -575,6 +574,19 @@ class Basic(with_metaclass(ManagedProperties)):
         True
         >>> (I*exp_polar(I*pi*2)).is_comparable
         False
+
+        A False result does not mean that `self` cannot be rewritten
+        into a form that would be comparable. For example, the
+        difference computed below is zero but without simplification
+        it does not evaluate to a zero with precision:
+
+        >>> e = 2**pi*(1 + 2**pi)
+        >>> dif = e - e.expand()
+        >>> dif.is_comparable
+        False
+        >>> dif.n(2)._prec
+        1
+
         """
         is_real = self.is_real
         if is_real is False:
@@ -662,12 +674,6 @@ class Basic(with_metaclass(ManagedProperties)):
         """
         return self.args
 
-    @deprecated(useinstead="iter(self.args)", issue=7717, deprecated_since_version="0.7.6")
-    def iter_basic_args(self):
-        """
-        Iterates arguments of ``self``.
-        """
-        return iter(self.args)
 
     def as_poly(self, *gens, **args):
         """Converts ``self`` to a polynomial or returns ``None``.
@@ -697,7 +703,7 @@ class Basic(with_metaclass(ManagedProperties)):
         except PolynomialError:
             return None
 
-    def as_content_primitive(self, radical=False):
+    def as_content_primitive(self, radical=False, clear=True):
         """A stub to allow Basic args (like Tuple) to be skipped when computing
         the content and primitive components of an expression.
 
@@ -1597,20 +1603,6 @@ class Basic(with_metaclass(ManagedProperties)):
                 else:
                     return self
 
-    @property
-    @deprecated(useinstead="is_finite", issue=8071, deprecated_since_version="0.7.6")
-    def is_bounded(self):
-        return super(Basic, self).__getattribute__('is_finite')
-
-    @property
-    @deprecated(useinstead="is_infinite", issue=8071, deprecated_since_version="0.7.6")
-    def is_unbounded(self):
-        return super(Basic, self).__getattribute__('is_infinite')
-
-    @deprecated(useinstead="is_zero", issue=8071, deprecated_since_version="0.7.6")
-    def is_infinitesimal(self):
-        return super(Basic, self).__getattribute__('is_zero')
-
 
 class Atom(Basic):
     """
@@ -1643,7 +1635,6 @@ class Atom(Basic):
 
     @cacheit
     def sort_key(self, order=None):
-        from sympy.core import S
         return self.class_key(), (1, (str(self),)), S.One.sort_key(), S.One
 
     def _eval_simplify(self, ratio, measure):
