@@ -98,7 +98,7 @@ def test_diff_symbols():
 def test_Function():
     class myfunc(Function):
         @classmethod
-        def eval(cls, x):
+        def eval(cls, x):  # one arg
             return
 
     assert myfunc.nargs == FiniteSet(1)
@@ -107,12 +107,13 @@ def test_Function():
 
     class myfunc(Function):
         @classmethod
-        def eval(cls, *x):
+        def eval(cls, *x):  # star args
             return
 
     assert myfunc.nargs == S.Naturals0
     assert myfunc(x).nargs == S.Naturals0
 
+
 def test_nargs():
     f = Function('f')
     assert f.nargs == S.Naturals0
@@ -124,6 +125,9 @@ def test_nargs():
     assert log(2).nargs == FiniteSet(1, 2)
     assert Function('f', nargs=2).nargs == FiniteSet(2)
     assert Function('f', nargs=0).nargs == FiniteSet(0)
+    assert Function('f', nargs=(0, 1)).nargs == FiniteSet(0, 1)
+    assert Function('f', nargs=None).nargs == S.Naturals0
+    raises(ValueError, lambda: Function('f', nargs=()))
 
 
 def test_Lambda():
@@ -153,7 +157,7 @@ def test_Lambda():
 
     assert Lambda(x, 2*x) + Lambda(y, 2*y) == 2*Lambda(x, 2*x)
     assert Lambda(x, 2*x) not in [ Lambda(x, x) ]
-    raises(ValueError, lambda: Lambda(1, x))
+    raises(TypeError, lambda: Lambda(1, x))
     assert Lambda(x, 1)(1) is S.One
 
 
@@ -230,8 +234,9 @@ def test_Subs():
     assert e1 + e2 == 2*e1
     assert e1.__hash__() == e2.__hash__()
     assert Subs(z*f(x + 1), x, 1) not in [ e1, e2 ]
-    assert Derivative(
-        f(x), x).subs(x, g(x)) == Subs(Derivative(f(x), x), (x,), (g(x),))
+    assert Derivative(f(x), x).subs(x, g(x)) == Derivative(f(g(x)), g(x))
+    assert Derivative(f(x), x).subs(x, x + y) == Subs(Derivative(f(x), x),
+        (x,), (x + y))
     assert Subs(f(x)*cos(y) + z, (x, y), (0, pi/3)).n(2) == \
         Subs(f(x)*cos(y) + z, (x, y), (0, pi/3)).evalf(2) == \
         z + Rational('1/2').n(2)*f(0)
@@ -601,7 +606,7 @@ def test_issue_4711():
 
 def test_nfloat():
     from sympy.core.basic import _aresame
-    from sympy.polys.rootoftools import RootOf
+    from sympy.polys.rootoftools import rootof
 
     x = Symbol("x")
     eq = x**(S(4)/3) + 4*x**(S(1)/3)/3
@@ -628,7 +633,7 @@ def test_nfloat():
         9.99999999800000e-11
 
     # issue 7122
-    eq = cos(3*x**4 + y)*RootOf(x**5 + 3*x**3 + 1, 0)
+    eq = cos(3*x**4 + y)*rootof(x**5 + 3*x**3 + 1, 0)
     assert str(nfloat(eq, exponent=False, n=1)) == '-0.7*cos(3.0*x**4 + y)'
 
 
