@@ -205,7 +205,7 @@ class exp(ExpBase):
         else:
             raise ArgumentIndexError(self, argindex)
 
-    def _eval_refine(self):
+    def _eval_refine(self, assumptions):
         from sympy.assumptions import ask, Q
         arg = self.args[0]
         if arg.is_Mul:
@@ -228,6 +228,7 @@ class exp(ExpBase):
     @classmethod
     def eval(cls, arg):
         from sympy.assumptions import ask, Q
+        from sympy.calculus import AccumBounds
         if arg.is_Number:
             if arg is S.NaN:
                 return S.NaN
@@ -241,6 +242,8 @@ class exp(ExpBase):
                 return S.Zero
         elif arg.func is log:
             return arg.args[0]
+        elif isinstance(arg, AccumBounds):
+            return AccumBounds(exp(arg.min), exp(arg.max))
         elif arg.is_Mul:
             if arg.is_number or arg.is_Symbol:
                 coeff = arg.coeff(S.Pi*S.ImaginaryUnit)
@@ -483,6 +486,7 @@ class log(Function):
     @classmethod
     def eval(cls, arg, base=None):
         from sympy import unpolarify
+        from sympy.calculus import AccumBounds
         arg = sympify(arg)
 
         if base is not None:
@@ -530,6 +534,11 @@ class log(Function):
             return arg.args[0]
         elif arg.func is exp_polar:
             return unpolarify(arg.exp)
+        elif isinstance(arg, AccumBounds):
+            if arg.min.is_positive:
+                return AccumBounds(log(arg.min), log(arg.max))
+            else:
+                return
 
         if arg.is_number:
             if arg.is_negative:
