@@ -1,4 +1,3 @@
 from .boolalg import (to_cnf, to_dnf, to_nnf, And, Or, Not, Xor, Nand, Nor, Implies,
-    Equivalent, ITE, POSform, SOPform, simplify_logic,
-    bool_equal, bool_map, true, false)
+    Equivalent, ITE, POSform, SOPform, simplify_logic, bool_map, true, false)
 from .inference import satisfiable
