@@ -293,8 +293,23 @@ class PrettyPrinter(Printer):
         return pform
 
     def _print_Cycle(self, dc):
-        from sympy.combinatorics.permutations import Permutation
-        return self._print_tuple(Permutation(dc.as_list()).cyclic_form)
+        from sympy.combinatorics.permutations import Permutation, Cycle
+        # for Empty Cycle
+        if dc == Cycle():
+            cyc = stringPict('')
+            return prettyForm(*cyc.parens())
+
+        dc_list = Permutation(dc.list()).cyclic_form
+        # for Identity Cycle
+        if dc_list == []:
+            cyc = self._print(dc.size - 1)
+            return prettyForm(*cyc.parens())
+
+        cyc = stringPict('')
+        for i in dc_list:
+            l = self._print(str(tuple(i)).replace(',', ''))
+            cyc = prettyForm(*cyc.right(l))
+        return cyc
 
     def _print_PDF(self, pdf):
         lim = self._print(pdf.pdf.args[0])
@@ -649,6 +664,13 @@ class PrettyPrinter(Printer):
     _print_ImmutableMatrix = _print_MatrixBase
     _print_Matrix = _print_MatrixBase
 
+    def _print_Trace(self, e):
+        D = self._print(e.arg)
+        D = prettyForm(*D.parens('(',')'))
+        D.baseline = D.height()//2
+        D = prettyForm(*D.left('\n'*(0) + 'tr'))
+        return D
+
 
     def _print_MatrixElement(self, expr):
         from sympy.matrices import MatrixSymbol
@@ -736,6 +758,13 @@ class PrettyPrinter(Printer):
 
         return prettyForm.__mul__(*args)
 
+    def _print_DotProduct(self, expr):
+        args = list(expr.args)
+
+        for i, a in enumerate(args):
+            args[i] = self._print(a)
+        return prettyForm.__mul__(*args)
+
     def _print_MatPow(self, expr):
         pform = self._print(expr.base)
         from sympy.matrices import MatrixSymbol
@@ -765,82 +794,77 @@ class PrettyPrinter(Printer):
 
         if not self._use_unicode:
             raise NotImplementedError("ASCII pretty printing of BasisDependent is not implemented")
-        class Fake(object):
-            baseline = 0
 
-            # slf to distinguish from self from _print_BasisDependent
-            def render(slf, *args, **kwargs):
-                if expr == expr.zero:
-                    return expr.zero._pretty_form
-                o1 = []
-                vectstrs = []
-                if isinstance(expr, Vector):
-                    items = expr.separate().items()
+        if expr == expr.zero:
+            return prettyForm(expr.zero._pretty_form)
+        o1 = []
+        vectstrs = []
+        if isinstance(expr, Vector):
+            items = expr.separate().items()
+        else:
+            items = [(0, expr)]
+        for system, vect in items:
+            inneritems = list(vect.components.items())
+            inneritems.sort(key = lambda x: x[0].__str__())
+            for k, v in inneritems:
+                #if the coef of the basis vector is 1
+                #we skip the 1
+                if v == 1:
+                    o1.append(u("") +
+                              k._pretty_form)
+                #Same for -1
+                elif v == -1:
+                    o1.append(u("(-1) ") +
+                              k._pretty_form)
+                #For a general expr
                 else:
-                    items = [(0, expr)]
-                for system, vect in items:
-                    inneritems = list(vect.components.items())
-                    inneritems.sort(key = lambda x: x[0].__str__())
-                    for k, v in inneritems:
-                        #if the coef of the basis vector is 1
-                        #we skip the 1
-                        if v == 1:
-                            o1.append(u("") +
-                                      k._pretty_form)
-                        #Same for -1
-                        elif v == -1:
-                            o1.append(u("(-1) ") +
-                                      k._pretty_form)
-                        #For a general expr
-                        else:
-                            #We always wrap the measure numbers in
-                            #parentheses
-                            arg_str = self._print(
-                                v).parens()[0]
+                    #We always wrap the measure numbers in
+                    #parentheses
+                    arg_str = self._print(
+                        v).parens()[0]
 
-                            o1.append(arg_str + ' ' + k._pretty_form)
-                        vectstrs.append(k._pretty_form)
+                    o1.append(arg_str + ' ' + k._pretty_form)
+                vectstrs.append(k._pretty_form)
 
-                #outstr = u("").join(o1)
-                if o1[0].startswith(u(" + ")):
-                    o1[0] = o1[0][3:]
-                elif o1[0].startswith(" "):
-                    o1[0] = o1[0][1:]
-                #Fixing the newlines
-                lengths = []
-                strs = ['']
-                for i, partstr in enumerate(o1):
-                    # XXX: What is this hack?
-                    if '\n' in partstr:
-                        tempstr = partstr
-                        tempstr = tempstr.replace(vectstrs[i], '')
-                        tempstr = tempstr.replace(u('\N{RIGHT PARENTHESIS UPPER HOOK}'),
-                                                  u('\N{RIGHT PARENTHESIS UPPER HOOK}')
-                                                  + ' ' + vectstrs[i])
-                        o1[i] = tempstr
-                o1 = [x.split('\n') for x in o1]
-                n_newlines = max([len(x) for x in o1])
-                for parts in o1:
-                    lengths.append(len(parts[0]))
-                    for j in range(n_newlines):
-                        if j+1 <= len(parts):
-                            if j >= len(strs):
-                                strs.append(' ' * (sum(lengths[:-1]) +
-                                                   3*(len(lengths)-1)))
-                            if j == 0:
-                                strs[0] += parts[0] + ' + '
-                            else:
-                                strs[j] += parts[j] + ' '*(lengths[-1] -
-                                                           len(parts[j])+
-                                                           3)
-                        else:
-                            if j >= len(strs):
-                                strs.append(' ' * (sum(lengths[:-1]) +
-                                                   3*(len(lengths)-1)))
-                            strs[j] += ' '*(lengths[-1]+3)
+        #outstr = u("").join(o1)
+        if o1[0].startswith(u(" + ")):
+            o1[0] = o1[0][3:]
+        elif o1[0].startswith(" "):
+            o1[0] = o1[0][1:]
+        #Fixing the newlines
+        lengths = []
+        strs = ['']
+        for i, partstr in enumerate(o1):
+            # XXX: What is this hack?
+            if '\n' in partstr:
+                tempstr = partstr
+                tempstr = tempstr.replace(vectstrs[i], '')
+                tempstr = tempstr.replace(u('\N{RIGHT PARENTHESIS UPPER HOOK}'),
+                                          u('\N{RIGHT PARENTHESIS UPPER HOOK}')
+                                          + ' ' + vectstrs[i])
+                o1[i] = tempstr
+        o1 = [x.split('\n') for x in o1]
+        n_newlines = max([len(x) for x in o1])
+        for parts in o1:
+            lengths.append(len(parts[0]))
+            for j in range(n_newlines):
+                if j+1 <= len(parts):
+                    if j >= len(strs):
+                        strs.append(' ' * (sum(lengths[:-1]) +
+                                           3*(len(lengths)-1)))
+                    if j == 0:
+                        strs[0] += parts[0] + ' + '
+                    else:
+                        strs[j] += parts[j] + ' '*(lengths[-1] -
+                                                   len(parts[j])+
+                                                   3)
+                else:
+                    if j >= len(strs):
+                        strs.append(' ' * (sum(lengths[:-1]) +
+                                           3*(len(lengths)-1)))
+                    strs[j] += ' '*(lengths[-1]+3)
 
-                return u('\n').join([s[:-3] for s in strs])
-        return Fake()
+        return prettyForm(u('\n').join([s[:-3] for s in strs]))
 
     def _print_Piecewise(self, pexpr):
 
@@ -1429,7 +1453,7 @@ class PrettyPrinter(Printer):
             from sympy import Pow
             return self._print(Pow(p.sets[0], len(p.sets), evaluate=False))
         else:
-            prod_char = u('\xd7')
+            prod_char = u("\N{MULTIPLICATION SIGN}") if self._use_unicode else 'x'
             return self._print_seq(p.sets, None, None, ' %s ' % prod_char,
                                    parenthesize=lambda set: set.is_Union or
                                    set.is_Intersection or set.is_ProductSet)
@@ -1473,19 +1497,27 @@ class PrettyPrinter(Printer):
 
             return self._print_seq(i.args[:2], left, right)
 
+    def _print_AccumuBounds(self, i):
+        left = '<'
+        right = '>'
+
+        return self._print_seq(i.args[:2], left, right)
+
     def _print_Intersection(self, u):
 
-        delimiter = ' %s ' % pretty_atom('Intersection')
+        delimiter = ' %s ' % pretty_atom('Intersection', 'n')
 
         return self._print_seq(u.args, None, None, delimiter,
-                parenthesize=lambda set: set.is_ProductSet or set.is_Union)
+                               parenthesize=lambda set: set.is_ProductSet or
+                               set.is_Union or set.is_Complement)
 
     def _print_Union(self, u):
 
-        union_delimiter = ' %s ' % pretty_atom('Union')
+        union_delimiter = ' %s ' % pretty_atom('Union', 'U')
 
         return self._print_seq(u.args, None, None, union_delimiter,
-             parenthesize=lambda set: set.is_ProductSet or set.is_Intersection)
+                               parenthesize=lambda set: set.is_ProductSet or
+                               set.is_Intersection or set.is_Complement)
 
     def _print_SymmetricDifference(self, u):
         if not self._use_unicode:
@@ -1524,8 +1556,15 @@ class PrettyPrinter(Printer):
         else:
             inn = 'in'
             _and = 'and'
+
         variables = self._print_seq(Tuple(ts.sym))
-        cond = self._print(ts.condition.as_expr())
+        try:
+            cond = self._print(ts.condition.as_expr())
+        except AttributeError:
+            cond = self._print(ts.condition)
+            if self._use_unicode:
+                cond = self._print_seq(cond, "(", ")")
+
         bar = self._print("|")
         base = self._print(ts.base_set)
 
@@ -1537,8 +1576,8 @@ class PrettyPrinter(Printer):
             inn = u("\N{SMALL ELEMENT OF}")
         else:
             inn = 'in'
-        variables = self._print_seq(ts.args[0].variables)
-        expr = self._print(ts.args[0].expr)
+        variables = self._print_seq(ts.variables)
+        expr = self._print(ts.expr)
         bar = self._print("|")
         prodsets = self._print(ts.sets)
 
@@ -1678,10 +1717,10 @@ class PrettyPrinter(Printer):
         else:
             return self._print(expr.as_expr())
 
-    def _print_RootOf(self, expr):
+    def _print_ComplexRootOf(self, expr):
         args = [self._print_Add(expr.expr, order='lex'), expr.index]
         pform = prettyForm(*self._print_seq(args).parens())
-        pform = prettyForm(*pform.left('RootOf'))
+        pform = prettyForm(*pform.left('CRootOf'))
         return pform
 
     def _print_RootSum(self, expr):
